@@ -1,7 +1,10 @@
+"""The HEPi package aims to automize cluster computations for parameter scans with the option to produce plots. """
+from .output import *
 from .input import *
 from .results import *
 from .util import *
 from .plot import *
+from .run import *
 
 import pkg_resources as pkg  # part of setuptools
 #import json
