@@ -19,47 +19,19 @@ from particle.converters.bimap import DirectionalMaps
 import matplotlib.cm as cm
 from matplotlib import colors
 
-from .input import Input, get_input_dir
-from .util import get_name
+from .input import Input, get_output_dir
+from .util import  get_name
 from matplotlib.ticker import ScalarFormatter, NullFormatter
 from smpl import io
 from typing import List
 
-def tex_table(dict_list,key,fname,scale=True,pdf=True,yscale=1.):
- dl = dict_list
- mask = dl["NLO_SCALE"]!= np.array(None)
- lo = splot.unv(dl["LO"][mask])
- nlo = splot.unv(dl["NLO"][mask])
- nlo_plus_nll = splot.unv(dl["NLO_PLUS_NLL"][mask])
- with open(fname,'w+') as f:
-     for i in range(len(dl["LO"][mask])):
-        f.write(
-            "$" + io.gf(4).format(dl[key][mask][i]) + "$ \t&\t $"+
-            "{:.3f}".format(lo[i]*yscale) 
-                + "^{+"+"{:.1f}".format(dl["LO_SCALE_ERRPLUS"][mask][i]/lo[i]*100.)
-                + "\%}_{" +"{:.1f}".format(dl["LO_SCALE_ERRMINUS"][mask][i]/lo[i]*100.)
-                +  "\%}$ \t&\t $"+
-            "{:.3f}".format(nlo[i]*yscale) 
-                + "^{+"+"{:.1f}".format(dl["NLO_SCALE_ERRPLUS"][mask][i]/nlo[i]*100.)
-                + ("\%+"+"{:.1f}".format(dl["NLO_PDF_ERRPLUS"][mask][i] /nlo[i]*100.) if pdf else "")
-                + "\%}_{" +"{:.1f}".format(dl["NLO_SCALE_ERRMINUS"][mask][i]/nlo[i]*100.)
-                + ("\%"+"{:.1f}".format(dl["NLO_PDF_ERRMINUS"][mask][i]/nlo[i]*100.) if pdf else "")
-                +  "\%}$ \t&\t $"+
-            "{:.3f}".format(nlo_plus_nll[i]*yscale) 
-                + "^{+"+"{:.1f}".format(dl["NLO_PLUS_NLL_SCALE_ERRPLUS"][mask][i]/nlo_plus_nll[i]*100.)
-                + ("\%+"+"{:.1f}".format(dl["NLO_PLUS_NLL_PDF_ERRPLUS"][mask][i]/nlo_plus_nll[i]*100.) if pdf else "")
-                + "\%}_{" +"{:.1f}".format(dl["NLO_PLUS_NLL_SCALE_ERRMINUS"][mask][i]/nlo_plus_nll[i]*100.)
-                + ("\%"+"{:.1f}".format(dl["NLO_PLUS_NLL_PDF_ERRMINUS"][mask][i]/nlo_plus_nll[i]*100.) if pdf else "")
-                +  "\%}$ "+
-            "\\\\\n"
-        )
 
-def title(axe,i:Input,scenario="",diff_L_R=None,extra="",**kwargs):
+def title(axe,i:Input,scenario="",diff_L_R=None,extra="",cms_energy=True,pdf_info=True,**kwargs):
     axe.set_title(
         "$pp\\to"+get_name(i.particle1)+get_name(i.particle2) + "$"
-        #+" at $\\sqrt{S} = " +str(i.energy/1000) + "$ TeV"
+        +(" at $\\sqrt{S} = " +str(i.energy/1000) + "$ TeV" if cms_energy else "")
         +" for " +(i.slha.split(".")[0] if scenario =="" else scenario)
-        #+" with " + i.pdf_nlo
+        +(" with " + i.pdf_nlo if pdf_info else "")
         + " " + extra
     )
 
@@ -102,12 +74,6 @@ def combined_plot(func,dict_list,t,*args,label=None,fill = False,fmt=".",interpo
 
 
 
-def get_mass(l, id):
-    ret = []
-    for s in l["slha"]:
-        d = pyslha.read(get_input_dir() + s)
-        ret.append(d.blocks["MASS"][abs(id)])
-    return np.array(ret)
 
 def mass_plot(dict_list,  y, part, logy=True, yaxis="$\\sigma$ [pb]", yscale=1., label=None,**kwargs):
     dict_list["mass_"+ str(part)] = get_mass(dict_list, abs(part))
@@ -122,6 +88,19 @@ def mass_vplot(dict_list,  y,part, logy=True, yaxis="$\\sigma$ [pb]", yscale=1.,
 #          xaxis="$M_{"+get_name(part) + "}$ [GeV]", yaxis=yaxis, logy=logy, yscale=yscale,mask=mask,**kwargs)
 
 
+def get_mass(l : dict, id : int ):
+    """
+    Get the mass of particle with id `id` out of the list in the "slha" element in the dict.
+
+    Returns
+        :obj:`list` of float : masses of particles in each element of the dict list.
+    """
+    ret = []
+    for s in l["slha"]:
+        d = pyslha.read(get_output_dir() + s)
+        ret.append(d.blocks["MASS"][abs(id)])
+    return np.array(ret)
+
 def plot(dict_list, x, y, label=None, xaxis="E [GeV]", yaxis="$\\sigma$ [pb]",ratio=False,K=False,K_plus_1=False, logy=True, yscale=1.,mask=None,**kwargs):
     # TODO use kwargs
     if label is None:
@@ -154,7 +133,7 @@ def index_open(var,idx):
 def slha_data(li,index_list):
     vx = []
     for l in li:
-        b = pyslha.read(get_input_dir() + l.slha)
+        b = pyslha.read(get_output_dir() + l.slha)
         vx.append(index_open(b.blocks,index_list))
     return np.array(vx)
 
@@ -164,7 +143,7 @@ def slha_plot(li,x,y,**kwargs):
 
     vplot(np.array(vx),np.array(vy),**kwargs)
 
-def vplot(x, y, label=None, xaxis="E [GeV]", yaxis="$\\sigma$ [pb]", logy=True, yscale=1.,interpolate=True,plot_data=True,data_color=None,mask=-1,fill =False,data_fmt=".",fmt="-",**kwargs):
+def vplot(x, y, label=None, xaxis="E [GeV]", yaxis="$\\sigma$ [pb]", logy=True, yscale=1.,interpolate=True,plot_data=True,data_color=None,mask=-1,fill =False,data_fmt=".",fmt="-",print_area=False,**kwargs):
     color = data_color
     if label is None:
         #label = "??"
@@ -200,7 +179,8 @@ def vplot(x, y, label=None, xaxis="E [GeV]", yaxis="$\\sigma$ [pb]", logy=True,
         kargs = {}
         if not plot_data:
             kargs = {'xaxis':xaxis, 'yaxis':yaxis,'label':label}
-        print('computed AUC using sklearn.metrics.auc: {}'.format(auc(xnew,power_smooth*yscale)))
+        if print_area:
+            print('computed AUC using sklearn.metrics.auc: {}'.format(auc(xnew,power_smooth*yscale)))
         splot.data(xnew, power_smooth*yscale, logy=logy, fmt=fmt
               , init=False, data_color=color,  **kargs,**kwargs)
     if fill:
@@ -277,7 +257,7 @@ def err_plt(axes,x,y,label=None,error=False):
         l = axes.plot(x[ind], splot.unv(y)[ind], label=v)
         return l[0]
 
-def scale_plot(dict_list, vl, seven_point_band=False, cont=False,error=True,li=None,plehn_color=False,yscale=1.,unit="pb",**kwargs):
+def scale_plot(dict_list, vl, seven_point_band=False,cont=False,error=True,li=None,plehn_color=False,yscale=1.,unit="pb", yaxis=None,**kwargs):
     global fig, axs,lines,labels
     cycle_safe = mpl.rcParams['axes.prop_cycle'] 
     if plehn_color:
@@ -367,7 +347,7 @@ def scale_plot(dict_list, vl, seven_point_band=False, cont=False,error=True,li=N
             labels.append("$\\Delta \\sigma_{\\mathrm{" + v.replace("NLO_PLUS_NLL","NLO+NLL").replace(" ","\\<space>") + "} }$")
 
 
-    axs[0].set_ylabel("$\sigma$ ["+unit+"]")
+    axs[0].set_ylabel("$\sigma$ ["+unit+"]" if yaxis is None else yaxis)
 
     axs[0].set_xscale("log")
     axs[0].set_xlim(np.min(mf), np.max(mf))
@@ -415,7 +395,7 @@ def scale_plot(dict_list, vl, seven_point_band=False, cont=False,error=True,li=N
 
     
 
-def central_scale_plot(dict_list, vl, cont=False,error=True,yscale=1.,unit="pb"):
+def central_scale_plot(dict_list, vl, cont=False,error=True,yscale=1.,unit="pb",yaxis=None):
     global fig, axs
     if not cont:
         fig, axs = plt.subplots(3, 1, figsize=(12, 8), sharex=True)
@@ -446,7 +426,7 @@ def central_scale_plot(dict_list, vl, cont=False,error=True,yscale=1.,unit="pb")
         axs[1].plot([], [], ' ', label="$\mu_F=\mu_0$, $\mu_R=\mu$")
         axs[2].plot([], [], ' ', label="$\mu_R=\mu_0$, $\mu_F=\mu$")
 
-    axs[1].set_ylabel("$\sigma$ ["+unit+"]")
+    axs[1].set_ylabel("$\sigma$ ["+unit+"]" if yaxis is None else yaxis)
 
     axs[0].set_xscale("log")
     #axs[0].set_xlim(np.min(mf), np.max(mf))
