@@ -1,17 +1,38 @@
 from hepi.input import Order
-from .. import Input, Result, LD2DL, get_output_dir, get_input_dir
+from .. import Input, Result,   get_output_dir
 import re
 from uncertainties import ufloat_fromstr
 from string import Template
 import pkgutil
-import warnings
 import os
 
+
 class ResumminoResult(Result):
     """
     Resummino Result Data.
+
+    Attributes:
+        VNLO (double): virtual NLO result.
+        RNLO (double): real NLO result.
+        P_PLUS_K (double): collineare remainders P+K NLO result.
+        RNLOG (double): real NLO gluon result.
+        RNLOQ (double): real NLO quark result.
+        VNLO_PLUS_P_PLUS_K (double): VNLO+P+K result.
+        RNLO_PLUS_VNLO_PLUS_P_PLUS_K (double): RNLO+VNLO+P+K result.
     """
     def __init__(self, lo, nlo, nlo_plus_nll, vnlo, p_plus_k, rnlog, rnloq):
+        """
+        Sets given and computes dependent ``Attributes``.
+
+        Args:
+            lo (:obj:`double`): corresponds to :attr:`LO`.
+            nlo (:obj:`double`): corresponds to :attr:`NLO`.
+            nlo_plus_nll (:obj:`double`): corresponds to :attr:`NLO_PLUS_NLL`.
+            vnlo (:obj:`double`): corresponds to :attr:`VNLO`.
+            p_plus_k (:obj:`double`): corresponds to :attr:`P_PLUS_K`.
+            rnlog (:obj:`double`): corresponds to :attr:`RNLOG`.
+            rnloq (:obj:`double`): corresponds to :attr:`RNLOQ`.
+        """
         Result.__init__(self, lo, nlo, nlo_plus_nll)
         self.VNLO = vnlo
         self.P_PLUS_K = p_plus_k
@@ -30,9 +51,19 @@ class ResumminoResult(Result):
         else:
             self.RNLO_PLUS_VNLO_PLUS_P_PLUS_K = None
 
-def is_valid(file:str,p:Input,d):
+# TODO move functions to results
+
+def is_valid(file:str,p:Input,d) -> bool:
     """
     Verifies that an file is a complete output.
+
+    Args:
+        file (str): File path to be parsed.
+        p (:class:`hepi.Input`): Onput parameters.
+        d (:obj:`dict`): Param dictionary.
+
+    Returns:
+        bool : True if `file` could be parsed.
     """
     order = p.order
     data = pkgutil.get_data(__name__, "plot_template.in").decode(
@@ -41,7 +72,7 @@ def is_valid(file:str,p:Input,d):
     result = src.substitute(d)
     sname = d['slha']
     with open(file,mode='r') as f:
-        with open(get_input_dir() + sname, 'r') as sf:
+        with open(get_output_dir() + sname, 'r') as sf:
             if not f.read().startswith(result + "\n\n" + sf.read()):
                 #warnings.warn("Possible hash collision in " + file + " -> deleted",RuntimeWarning)
                 os.remove(file)
@@ -60,9 +91,16 @@ def is_valid(file:str,p:Input,d):
     return False
 
 
-def parse_single(file) -> ResumminoResult:
+def parse_single(file : str) -> ResumminoResult:
     """
-    Extracts LO, NLO and NLO+NLL from resummino output file.
+    Extracts LO, NLO and NLO+NLL from Resummino output file.
+
+    Args:
+        file (str): File path to be parsed.
+
+    Returns:
+        :class:`ResumminoResult` : If a value is not found in the file None is used.
+
     """
     # TODO generalize units like RS
     lo_pattern = re.compile(r'^LO = \((.*)\) pb')
